@@ -177,21 +177,18 @@ class testmatchdecider extends XapianMatchDecider {
     }
 }
 
-if (defined('PHP_VERSION_ID') && PHP_VERSION_ID >= 50400) {
-    print "Skipping known failure subclassing Xapian classes in PHP under PHP 5.4+\n";
-} else {
-    $query = new XapianQuery($stem->apply("out"));
-    $enquire = new XapianEnquire($db);
-    $enquire->set_query($query);
-    $mdecider = new testmatchdecider();
-    $mset = $enquire->get_mset(0, 10, null, $mdecider);
-    if ($mset->size() != 1) {
-	print "Unexpected number of documents returned by match decider (".$mset->size().")\n";
-	exit(1);
-    }
-    if ($mset->get_docid(0) != 2) {
-	print "MatchDecider mset has wrong docid in\n";
-    }
+$query = new XapianQuery($stem->apply("out"));
+$enquire = new XapianEnquire($db);
+$enquire->set_query($query);
+$mdecider = new testmatchdecider();
+$mset = $enquire->get_mset(0, 10, null, $mdecider);
+if ($mset->size() != 1) {
+    print "Unexpected number of documents returned by match decider (".$mset->size().")\n";
+    exit(1);
+}
+if ($mset->get_docid(0) != 2) {
+    print "MatchDecider mset has wrong docid in\n";
+    exit(1);
 }
 
 if (XapianQuery::OP_ELITE_SET != 10) {
@@ -418,4 +415,17 @@ $indexer->set_document($doc);
 $indexer->index_text("I ask nothing in return");
 $indexer->index_text_without_positions("Tea time");
 
+# Test reference tracking and regression test for #659.
+$qp = new XapianQueryParser();
+{
+    $stop = new XapianSimpleStopper();
+    $stop->add('a');
+    $qp->set_stopper($stop);
+}
+$query = $qp->parse_query('a b');
+if ($query->get_description() !== 'Xapian::Query(b:(pos=2))') {
+    print "XapianQueryParser::set_stopper() didn't work as expected - result was ".$query->get_description()."\n";
+    exit(1);
+}
+
 ?>
